@@ -17,7 +17,7 @@ use App::VTide::Hooks;
 use Path::Tiny;
 use YAML::Syck qw/ LoadFile DumpFile /;
 
-our $VERSION = version->new('0.0.5');
+our $VERSION = version->new('0.0.6');
 
 has config => (
     is      => 'rw',
@@ -54,13 +54,13 @@ sub run {
                     print join ' ', sort @sub_commands;
                     return;
                 }
-                elsif ( grep {/^$sub_command/} @sub_commands ) {
+                elsif ( grep {/^$sub_command./} @sub_commands ) {
                     print join ' ', sort grep {/^$sub_command/} @sub_commands;
                     return;
                 }
                 elsif ( ! $self->sub_commands->{$sub_command} ) {
                     unshift @{$option->files}, $sub_command;
-                    $sub_command = 'start';
+                    $sub_command = $ENV{VTIDE_DIR} ? 'edit' : 'start';
                 }
                 eval {
                     $self->load_subcommand( $sub_command, $option )->auto_complete();
@@ -85,7 +85,7 @@ sub run {
 
     my $subcommand = eval { $self->load_subcommand( $opt->cmd, $opt ) };
     if ( ! $subcommand ) {
-        $subcommand = $self->load_subcommand( 'start', $opt );
+        $subcommand = $self->load_subcommand( $ENV{VTIDE_DIR} ? 'edit' : 'start', $opt );
         my (undef, $dir) = $subcommand->session_dir($opt->cmd);
         if ( !$dir ) {
             my $error = $@;
@@ -160,7 +160,7 @@ App::VTide - A vim/tmux based IDE for the terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide version 0.0.5
+This documentation refers to App::VTide version 0.0.6
 
 =head1 SYNOPSIS
 
