@@ -18,7 +18,7 @@ use File::chdir;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.5');
+our $VERSION = version->new('0.0.6');
 our $NAME    = 'run';
 our $OPTIONS = [
     'name|n=s',
@@ -199,7 +199,9 @@ sub command {
             : ( $params->{command} );
     }
 
-    my $editor = ref $params->{editor}{command} || $self->config->get->{editor}{command};
+    my $editor = ref $params->{editor}{command}
+        ? $params->{editor}{command}
+        : $self->config->get->{editor}{command};
 
     my @files;
     my @globs  = ref $params->{edit} ? @{ $params->{edit} } : ( $params->{edit} );
@@ -305,7 +307,7 @@ App::VTide::Command::Run - Run a terminal command
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Run version 0.0.5
+This documentation refers to App::VTide::Command::Run version 0.0.6
 
 =head1 SYNOPSIS
 
